@@ -4,7 +4,7 @@ from rest_framework import authentication, exceptions
 from django.utils.translation import gettext_lazy as _
 from requests.exceptions import ConnectionError, HTTPError, Timeout
 
-from adatoolbox.domain.auth.settings import settings
+from adatoolbox.domain.auth.settings import API_AD_URL
 # from core.exceptions.gateway_timeout import GatewayTimeout
 
 
@@ -18,7 +18,7 @@ class AuthApiAuthentication(authentication.BaseAuthentication):
 
         try:
             headers = {"Authorization": f"{token} "}
-            url = f"{settings.API_AD_URL}/api-ad/api/usuarios/userdata/"
+            url = f"{API_AD_URL}/api-ad/api/usuarios/userdata/"
             response = requests.get(url, headers=headers, timeout=10)
             response.raise_for_status()
             return response.json(), token
